@@ -39,7 +39,7 @@ MainWidget::MainWidget( QWidget* parent )
     klview->setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     klview->setFrameStyle(QFrame::NoFrame);
 
-    klview->setOptimizationFlags( QGraphicsView::DontClipPainter |
+    klview->setOptimizationFlags( 
                                   QGraphicsView::DontSavePainterState |
                                   QGraphicsView::DontAdjustForAntialiasing );
 
